@@ -27,7 +27,7 @@ class IvldClient(AbstractClient):
 
 
     def AddCustomPersonImage(self, request):
-        """增加自定义人脸图片，每个自定义人物最多可包含5张人脸图片
+        """增加自定义人脸图片，每个自定义人物最多可包含10张人脸图片
 
         请注意，与创建自定义人物一样，图片数据优先级优于图片URL优先级
 
@@ -38,7 +38,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddCustomPersonImage", params)
+            headers = request.headers
+            body = self.call("AddCustomPersonImage", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddCustomPersonImageResponse()
@@ -69,7 +70,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCustomCategory", params)
+            headers = request.headers
+            body = self.call("CreateCustomCategory", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateCustomCategoryResponse()
@@ -107,7 +109,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCustomGroup", params)
+            headers = request.headers
+            body = self.call("CreateCustomGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateCustomGroupResponse()
@@ -139,7 +142,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCustomPerson", params)
+            headers = request.headers
+            body = self.call("CreateCustomPerson", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateCustomPersonResponse()
@@ -167,7 +171,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDefaultCategories", params)
+            headers = request.headers
+            body = self.call("CreateDefaultCategories", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDefaultCategoriesResponse()
@@ -197,7 +202,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTask", params)
+            headers = request.headers
+            body = self.call("CreateTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTaskResponse()
@@ -225,7 +231,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteCustomCategory", params)
+            headers = request.headers
+            body = self.call("DeleteCustomCategory", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteCustomCategoryResponse()
@@ -253,7 +260,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteCustomPerson", params)
+            headers = request.headers
+            body = self.call("DeleteCustomPerson", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteCustomPersonResponse()
@@ -281,7 +289,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteCustomPersonImage", params)
+            headers = request.headers
+            body = self.call("DeleteCustomPersonImage", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteCustomPersonImageResponse()
@@ -311,7 +320,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteMedia", params)
+            headers = request.headers
+            body = self.call("DeleteMedia", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteMediaResponse()
@@ -329,6 +339,39 @@ class IvldClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteTask(self, request):
+        """删除任务信息
+
+        请注意，本接口**不会**删除媒资文件
+
+        只有已完成(成功或者失败)的任务可以删除，**正在执行中的任务不支持删除**
+
+        :param request: Request instance for DeleteTask.
+        :type request: :class:`tencentcloud.ivld.v20210903.models.DeleteTaskRequest`
+        :rtype: :class:`tencentcloud.ivld.v20210903.models.DeleteTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteTask", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeCustomCategories(self, request):
         """批量描述自定义人物分类信息
 
@@ -339,7 +382,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCustomCategories", params)
+            headers = request.headers
+            body = self.call("DescribeCustomCategories", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCustomCategoriesResponse()
@@ -367,7 +411,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCustomGroup", params)
+            headers = request.headers
+            body = self.call("DescribeCustomGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCustomGroupResponse()
@@ -395,7 +440,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCustomPersonDetail", params)
+            headers = request.headers
+            body = self.call("DescribeCustomPersonDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCustomPersonDetailResponse()
@@ -424,7 +470,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCustomPersons", params)
+            headers = request.headers
+            body = self.call("DescribeCustomPersons", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCustomPersonsResponse()
@@ -454,7 +501,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMedia", params)
+            headers = request.headers
+            body = self.call("DescribeMedia", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMediaResponse()
@@ -486,7 +534,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMedias", params)
+            headers = request.headers
+            body = self.call("DescribeMedias", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMediasResponse()
@@ -517,7 +566,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTask", params)
+            headers = request.headers
+            body = self.call("DescribeTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTaskResponse()
@@ -545,7 +595,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTaskDetail", params)
+            headers = request.headers
+            body = self.call("DescribeTaskDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTaskDetailResponse()
@@ -575,7 +626,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTasks", params)
+            headers = request.headers
+            body = self.call("DescribeTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTasksResponse()
@@ -600,7 +652,7 @@ class IvldClient(AbstractClient):
 
         当前URL只支持COS地址，其形式为`https://${Bucket}-${AppId}.cos.${Region}.myqcloud.com/${ObjectKey}`，其中`${Bucket}`为您的COS桶名称，Region为COS桶所在[可用区](https://cloud.tencent.com/document/product/213/6091)，`${ObjectKey}`为指向存储在COS桶内的待分析的视频的[ObjectKey](https://cloud.tencent.com/document/product/436/13324)
 
-        分析完成后，本产品将在您的`${Bucket}`桶内创建名为`${ObjectKey}-${task-start-time}`的目录(`task-start-time`形式为1970-01-01T08:08:08)并将分析结果将回传回该目录，也即，结构化分析结果(包括图片，JSON等数据)将会写回`https://${Bucket}-${AppId}.cos.${Region}.myqcloud.com/${ObjectKey}-${task-start-time}`目录
+        分析完成后，本产品将在您的`${Bucket}`桶内创建名为`${ObjectKey}_${task-create-time}`的目录(`task-create-time`形式为1970-01-01T08:08:08)并将分析结果将回传回该目录，也即，结构化分析结果(包括图片，JSON等数据)将会写回`https://${Bucket}-${AppId}.cos.${Region}.myqcloud.com/${ObjectKey}_${task-create-time}`目录
 
         :param request: Request instance for ImportMedia.
         :type request: :class:`tencentcloud.ivld.v20210903.models.ImportMediaRequest`
@@ -609,7 +661,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ImportMedia", params)
+            headers = request.headers
+            body = self.call("ImportMedia", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ImportMediaResponse()
@@ -627,6 +680,98 @@ class IvldClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyCallback(self, request):
+        """用户设置对应事件的回调地址
+
+        ### 回调事件消息通知协议
+
+        #### 网络协议
+        - 回调接口协议目前仅支持http/https协议；
+        - 请求：HTTP POST 请求，包体内容为 JSON，每一种消息的具体包体内容参见后文。
+        - 应答：HTTP STATUS CODE = 200，服务端忽略应答包具体内容，为了协议友好，建议客户应答内容携带 JSON： `{"code":0}`
+
+        #### 通知可靠性
+
+        事件通知服务具备重试能力，事件通知失败后会总计重试3次；
+        为了避免重试对您的服务器以及网络带宽造成冲击，请保持正常回包。触发重试条件如下：
+        - 长时间（5 秒）未回包应答。
+        - 应答 HTTP STATUS 不为200。
+
+
+        #### 回调接口协议
+
+        ##### 分析任务完成消息回调
+        | 参数名称 | 必选 | 类型 | 描述 |
+        |---------|---------|---------|---------|
+        | EventType | 是 | int | 回调时间类型，1-任务分析完成，2-媒资导入完成 |
+        | TaskId | 是 | String | 任务ID |
+        | TaskStatus | 是 | [TaskStatus](/document/product/1509/65063#TaskInfo) | 任务执行状态 |
+        | FailedReason | 是 | String | 若任务失败，该字段为失败原因 |
+
+
+        ##### 导入媒资完成消息回调
+        | 参数名称 | 必选 | 类型 | 描述 |
+        |---------|---------|---------|---------|
+        | EventType | 是 | int | 回调时间类型，1-任务分析完成，2-媒资导入完成 |
+        | MediaId | 是 | String | 媒资ID |
+        | MediaStatus | 是 | [MediaStatus](/document/product/1509/65063#MediaInfo) | 媒资导入状态|
+        | FailedReason | 是 | String | 若任务失败，该字段为失败原因 |
+
+        :param request: Request instance for ModifyCallback.
+        :type request: :class:`tencentcloud.ivld.v20210903.models.ModifyCallbackRequest`
+        :rtype: :class:`tencentcloud.ivld.v20210903.models.ModifyCallbackResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyCallback", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyCallbackResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryCallback(self, request):
+        """查询用户回调设置
+
+        :param request: Request instance for QueryCallback.
+        :type request: :class:`tencentcloud.ivld.v20210903.models.QueryCallbackRequest`
+        :rtype: :class:`tencentcloud.ivld.v20210903.models.QueryCallbackResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryCallback", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.QueryCallbackResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateCustomCategory(self, request):
         """更新自定义人物分类
 
@@ -640,7 +785,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateCustomCategory", params)
+            headers = request.headers
+            body = self.call("UpdateCustomCategory", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateCustomCategoryResponse()
@@ -668,7 +814,8 @@ class IvldClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateCustomPerson", params)
+            headers = request.headers
+            body = self.call("UpdateCustomPerson", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateCustomPersonResponse()
