@@ -28,7 +28,7 @@ class InitOralProcessRequest(AbstractModel):
         :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
         :param RefText: 被评估语音对应的文本，仅支持中文和英文。
-句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值无效。
+句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式RefText可以不填。
 关于RefText的文本键入要求，请参考[评测模式介绍](https://cloud.tencent.com/document/product/884/56131)。
 如需要在评测模式下使用自定义注音（支持中英文），可以通过设置「TextMode」参数实现，设置方式请参考[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
@@ -57,12 +57,8 @@ class InitOralProcessRequest(AbstractModel):
         :type SoeAppId: str
         :param IsLongLifeSession: 长效session标识，当该参数为1时，session的持续时间为300s，但会一定程度上影响第一个数据包的返回速度，且TransmitOralProcess必须同时为1才可生效。
         :type IsLongLifeSession: int
-        :param StorageMode: 音频存储模式
-0：不存储
-1：存储到公共对象存储，不会产生费用，存储时间为一个月。输出结果为该会话最后一个分片TransmitOralProcess 返回结果 AudioUrl 字段；
-2：永久存储音频，需要提工单申请，会产生一定的存储费用；
-3：自定义存储，将音频存储到自定义的腾讯云[对象存储](https://cloud.tencent.com/product/cos)中。
-注：对可用性要求较高的用户建议自行存储至腾讯云COS。
+        :param StorageMode: 音频存储模式，此参数已废弃，无需设置，设置与否都默认为0不存储；
+注：有存储需求的用户建议自行存储至腾讯云COS[对象存储](https://cloud.tencent.com/product/cos)使用。
         :type StorageMode: int
         :param SentenceInfoEnabled: 输出断句中间结果标识
 0：不输出
@@ -72,6 +68,7 @@ class InitOralProcessRequest(AbstractModel):
         :param ServerType: 评估语言
 0：英文
 1：中文
+ServerType不填默认为0
         :type ServerType: int
         :param IsAsync: 异步模式标识
 0：同步模式
@@ -148,13 +145,14 @@ class Keyword(AbstractModel):
 
     def __init__(self):
         r"""
-        :param RefText: 被评估语音对应的文本，句子模式下不超过个 20 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值无效。如需要在单词模式和句子模式下使用自定义音素，可以通过设置 TextMode 使用[音素标注](https://cloud.tencent.com/document/product/884/33698)。
+        :param RefText: 被评估语音对应的文本，句子模式下不超过个 20 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式RefText可以不填。如需要在单词模式和句子模式下使用自定义音素，可以通过设置 TextMode 使用[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
         :param EvalMode: 评估模式，0：词模式（中文评测模式下为文字模式），1：句子模式，2：段落模式，3：自由说模式，当为词模式评估时，能够提供每个音节的评估信息，当为句子模式时，能够提供完整度和流利度信息。
         :type EvalMode: int
         :param ScoreCoeff: 评价苛刻指数，取值为[1.0 - 4.0]范围内的浮点数，用于平滑不同年龄段的分数，1.0为小年龄段，4.0为最高年龄段
         :type ScoreCoeff: float
         :param ServerType: 评估语言，0：英文，1：中文。
+ServerType不填默认传0
         :type ServerType: int
         :param TextMode: 输入文本模式，0: 普通文本，1：[音素结构](https://cloud.tencent.com/document/product/884/33698)文本。
         :type TextMode: int
@@ -587,7 +585,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
         :param RefText: 被评估语音对应的文本，仅支持中文和英文。
-句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值无效。
+句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式RefText可以不填。
 关于RefText的文本键入要求，请参考[评测模式介绍](https://cloud.tencent.com/document/product/884/56131)。
 如需要在评测模式下使用自定义注音（支持中英文），可以通过设置「TextMode」参数实现，设置方式请参考[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
@@ -614,12 +612,8 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :type ScoreCoeff: float
         :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。
         :type SoeAppId: str
-        :param StorageMode: 音频存储模式
-0：不存储
-1：存储到公共对象存储，不会产生费用，存储时间为一个月。输出结果为该会话最后一个分片TransmitOralProcess 返回结果 AudioUrl 字段；
-2：永久存储音频，需要提工单申请，会产生一定的存储费用；
-3：自定义存储，将音频存储到自定义的腾讯云[对象存储](https://cloud.tencent.com/product/cos)中。
-注：对可用性要求较高的用户建议自行存储至腾讯云COS。
+        :param StorageMode: 音频存储模式，此参数已废弃，无需设置，设置与否都默认为0不存储；
+注：有存储需求的用户建议自行存储至腾讯云COS[对象存储](https://cloud.tencent.com/product/cos)使用。
         :type StorageMode: int
         :param SentenceInfoEnabled: 输出断句中间结果标识
 0：不输出
@@ -629,6 +623,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :param ServerType: 评估语言
 0：英文
 1：中文
+ServerType不填默认为0
         :type ServerType: int
         :param IsAsync: 异步模式标识
 0：同步模式
@@ -712,7 +707,7 @@ class TransmitOralProcessWithInitResponse(AbstractModel):
         :type SentenceInfoSet: list of SentenceInfo
         :param Status: 评估 session 状态，“Evaluating"：评估中、"Failed"：评估失败、"Finished"：评估完成
         :type Status: str
-        :param SuggestedScore: 建议评分，取值范围[0,100]，评分方式为建议评分 = 准确度（PronAccuracyfloat）× 完整度（PronCompletionfloat）×（2 - 完整度（PronCompletionfloat）），如若评分策略不符合请参考Words数组中的详细分数自定义评分逻辑。
+        :param SuggestedScore: 建议评分，取值范围[0,100]，评分方式为建议评分 = 准确度（PronAccuracy）× 完整度（PronCompletion）×（2 - 完整度（PronCompletion）），如若评分策略不符合请参考Words数组中的详细分数自定义评分逻辑。
         :type SuggestedScore: float
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
